@@ -1,6 +1,6 @@
 """ a 2D Mesh """
 
-from typing import List, Tuple
+from typing import Tuple
 
 import numpy as np
 from pydantic import Field
@@ -12,9 +12,6 @@ class Mesh(BaseModel):
     """[BaseClass] a `Mesh` describes how a `Structure` is discretized"""
 
 
-Meshes = List[Mesh]
-
-
 class Mesh2d(Mesh):
     """a 2D Mesh or `Mesh2D` describes how a `Structure` is discritized into a `Cell` or `CrossSection`"""
 
@@ -84,6 +81,3 @@ class Mesh2d(Mesh):
         except Exception:
             return False
         return x_eq and y_eq
-
-
-Meshes2d = List[Mesh2d]
